@@ -46,14 +46,6 @@
 #include "mate-settings-profile.h"
 #include "msd-background-manager.h"
 
-#if !GTK_CHECK_VERSION(3, 0, 0)
-#define cairo_surface_t		GdkPixmap
-#define cairo_surface_destroy	g_object_unref
-#define mate_bg_create_surface				mate_bg_create_pixmap
-#define mate_bg_set_surface_as_root			mate_bg_set_pixmap_as_root
-#define mate_bg_set_surface_as_root_with_crossfade	mate_bg_set_pixmap_as_root_with_crossfade
-#endif
-
 #define MATE_SESSION_MANAGER_DBUS_NAME "org.gnome.SessionManager"
 #define MATE_SESSION_MANAGER_DBUS_PATH "/org/gnome/SessionManager"
 
@@ -67,7 +59,9 @@ struct MsdBackgroundManagerPrivate {
 	GList           *scr_sizes;
 
 	gboolean         msd_can_draw;
+#if !GTK_CHECK_VERSION(3, 22, 0)
 	gboolean         caja_can_draw;
+#endif
 	gboolean         do_fade;
 	gboolean         draw_in_progress;
 
@@ -95,6 +89,7 @@ can_fade_bg (MsdBackgroundManager *manager)
 	return g_settings_get_boolean (manager->priv->settings, MATE_BG_KEY_BACKGROUND_FADE);
 }
 
+#if !GTK_CHECK_VERSION(3, 22, 0)
 /* Whether Caja is configured to draw desktop (show-desktop-icons) */
 static gboolean
 caja_can_draw_bg (MsdBackgroundManager *manager)
@@ -158,6 +153,7 @@ caja_is_drawing_bg (MsdBackgroundManager *manager)
 
 	return running;
 }
+#endif
 
 static void
 free_fade (MsdBackgroundManager *manager)
@@ -218,9 +214,13 @@ draw_background (MsdBackgroundManager *manager,
 {
 	MsdBackgroundManagerPrivate *p = manager->priv;
 
+#if GTK_CHECK_VERSION(3, 22, 0)
+        if (!p->msd_can_draw || p->draw_in_progress)
+		return;
+#else
 	if (!p->msd_can_draw || p->draw_in_progress || caja_is_drawing_bg (manager))
 		return;
-
+#endif
 	mate_settings_profile_start (NULL);
 
 	GdkDisplay *display   = gdk_display_get_default ();
@@ -263,10 +263,13 @@ on_screen_size_changed (GdkScreen            *screen,
 			MsdBackgroundManager *manager)
 {
 	MsdBackgroundManagerPrivate *p = manager->priv;
-
+#if GTK_CHECK_VERSION(3, 22, 0)
+        if (!p->msd_can_draw || p->draw_in_progress)
+                return;
+#else
 	if (!p->msd_can_draw || p->draw_in_progress || caja_is_drawing_bg (manager))
 		return;
-
+#endif
 	gint scr_num = gdk_screen_get_number (screen);
 	gchar *old_size = g_list_nth_data (manager->priv->scr_sizes, scr_num);
 	gchar *new_size = g_strdup_printf ("%dx%d", gdk_screen_get_width (screen),
@@ -337,14 +340,20 @@ settings_change_event_cb (GSettings            *settings,
 
 	/* Complements on_bg_handling_changed() */
 	p->msd_can_draw = msd_can_draw_bg (manager);
+#if GTK_CHECK_VERSION(3, 22, 0)
+	if (p->msd_can_draw && p->bg != NULL)
+	{
+		/* Defer signal processing to avoid making the dconf backend deadlock */
+		g_idle_add ((GSourceFunc) settings_change_event_idle_cb, manager);
+	}
+#else
 	p->caja_can_draw = caja_can_draw_bg (manager);
-
 	if (p->msd_can_draw && p->bg != NULL && !caja_is_drawing_bg (manager))
 	{
 		/* Defer signal processing to avoid making the dconf backend deadlock */
 		g_idle_add ((GSourceFunc) settings_change_event_idle_cb, manager);
 	}
-
+#endif
 	return FALSE;   /* let the event propagate further */
 }
 
@@ -402,7 +411,7 @@ on_bg_handling_changed (GSettings            *settings,
 	MsdBackgroundManagerPrivate *p = manager->priv;
 
 	mate_settings_profile_start (NULL);
-
+#if !GTK_CHECK_VERSION(3, 22, 0)
 	if (caja_is_drawing_bg (manager))
 	{
 		if (p->bg != NULL)
@@ -410,9 +419,11 @@ on_bg_handling_changed (GSettings            *settings,
 	}
 	else if (p->msd_can_draw && p->bg == NULL)
 	{
+#endif
 		setup_background (manager);
+#if !GTK_CHECK_VERSION(3, 22, 0)
 	}
-
+#endif
 	mate_settings_profile_end (NULL);
 }
 
@@ -467,6 +478,7 @@ on_session_manager_signal (GDBusProxy   *proxy,
 	}
 }
 
+#if !GTK_CHECK_VERSION(3, 22, 0)
 static void
 draw_bg_after_session_loads (MsdBackgroundManager *manager)
 {
@@ -495,6 +507,7 @@ draw_bg_after_session_loads (MsdBackgroundManager *manager)
 							   G_CALLBACK (on_session_manager_signal),
 							   manager);
 }
+#endif
 
 gboolean
 msd_background_manager_start (MsdBackgroundManager  *manager,
@@ -508,7 +521,9 @@ msd_background_manager_start (MsdBackgroundManager  *manager,
 	p->settings = g_settings_new (MATE_BG_SCHEMA);
 
 	p->msd_can_draw = msd_can_draw_bg (manager);
+#if !GTK_CHECK_VERSION(3, 22, 0)
 	p->caja_can_draw = caja_can_draw_bg (manager);
+#endif
 
 	g_signal_connect (p->settings, "changed::" MATE_BG_KEY_DRAW_BACKGROUND,
 			  G_CALLBACK (on_bg_handling_changed), manager);
@@ -521,14 +536,19 @@ msd_background_manager_start (MsdBackgroundManager  *manager,
 	 */
 	if (p->msd_can_draw)
 	{
+#if !GTK_CHECK_VERSION(3, 22, 0)
 		if (p->caja_can_draw)
 		{
+
 			draw_bg_after_session_loads (manager);
 		}
 		else
 		{
+#endif
 			setup_background (manager);
+#if !GTK_CHECK_VERSION(3, 22, 0)
 		}
+#endif
 	}
 
 	mate_settings_profile_end (NULL);
