@@ -22,14 +22,13 @@
 
 #include <gdk/gdk.h>
 #include <gdk/gdkx.h>
-#include <gtk/gtk.h>
 
 #include <sys/types.h>
 #include <X11/Xatom.h>
 
 #include "msd-input-helper.h"
 
-static gboolean
+gboolean
 supports_xinput_devices (void)
 {
         gint op_code, event, error;
@@ -42,7 +41,7 @@ supports_xinput_devices (void)
 }
 
 XDevice*
-device_is_touchpad (XDeviceInfo deviceinfo)
+device_is_touchpad (XDeviceInfo *deviceinfo)
 {
         XDevice *device;
         Atom realtype, prop;
@@ -50,15 +49,15 @@ device_is_touchpad (XDeviceInfo deviceinfo)
         unsigned long nitems, bytes_after;
         unsigned char *data;
 
-        if (deviceinfo.type != XInternAtom (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), XI_TOUCHPAD, False))
+        if (deviceinfo->type != XInternAtom (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), XI_TOUCHPAD, True))
                 return NULL;
 
-        prop = XInternAtom (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), "Synaptics Off", False);
+        prop = XInternAtom (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), "Synaptics Off", True);
         if (!prop)
                 return NULL;
 
         gdk_error_trap_push ();
-        device = XOpenDevice (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), deviceinfo.id);
+        device = XOpenDevice (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), deviceinfo->id);
         if (gdk_error_trap_pop () || (device == NULL))
                 return NULL;
 
@@ -66,19 +65,12 @@ device_is_touchpad (XDeviceInfo deviceinfo)
         if ((XGetDeviceProperty (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), device, prop, 0, 1, False,
                                 XA_INTEGER, &realtype, &realformat, &nitems,
                                 &bytes_after, &data) == Success) && (realtype != None)) {
-#if GTK_CHECK_VERSION (3, 0, 0)
                 gdk_error_trap_pop_ignored ();
-#else
-                gdk_error_trap_pop ();
-#endif
                 XFree (data);
                 return device;
         }
-#if GTK_CHECK_VERSION (3, 0, 0)
+
         gdk_error_trap_pop_ignored ();
-#else
-        gdk_error_trap_pop ();
-#endif
 
         XCloseDevice (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), device);
         return NULL;
@@ -104,7 +96,7 @@ touchpad_is_present (void)
         for (i = 0; i < n_devices; i++) {
                 XDevice *device;
 
-                device = device_is_touchpad (device_info[i]);
+                device = device_is_touchpad (&device_info[i]);
                 if (device != NULL) {
                         retval = TRUE;
                         break;
