@@ -42,7 +42,7 @@ typedef struct MsdLocatePointerData MsdLocatePointerData;
 struct MsdLocatePointerData
 {
   MsdTimeline *timeline;
-  GtkWindow *widget;
+  GtkWidget *widget;
   GdkWindow *window;
 
   gdouble progress;
@@ -50,57 +50,44 @@ struct MsdLocatePointerData
 
 static MsdLocatePointerData *data = NULL;
 
+static void
+msd_get_background_color (GtkStyleContext *context,
+                          GtkStateFlags    state,
+                          GdkRGBA         *color)
+{
+    GdkRGBA *c;
+
+    g_return_if_fail (color != NULL);
+    g_return_if_fail (GTK_IS_STYLE_CONTEXT (context));
+
+    gtk_style_context_get (context,
+                           state,
+                           "background-color", &c,
+                           NULL);
+    *color = *c;
+    gdk_rgba_free (c);
+}
+
 static void
 locate_pointer_paint (MsdLocatePointerData *data,
 		      cairo_t              *cr,
-		      gboolean              composited)
+		      gboolean              composite)
 {
-#if GTK_CHECK_VERSION (3, 0, 0)
   GdkRGBA color;
   gdouble progress, circle_progress;
   gint width, height, i;
-  GtkStyleContext *style;
-
-  color.red = color.green = color.blue = 0.7;
-  color.alpha = 0.;
-#else
-  GdkColor color;
-  gdouble progress, circle_progress;
-  gint width, height, i;
-  GtkStyle *style;
-
-  color.red = color.green = color.blue = 0xAAAA;
-#endif
+  GtkStyleContext *context;
 
   progress = data->progress;
 
   width = gdk_window_get_width (data->window);
   height = gdk_window_get_height (data->window);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-  style = gtk_widget_get_style_context (GTK_WIDGET (data->widget));
-  gtk_style_context_save (style);
-  gtk_style_context_set_state (style, GTK_STATE_FLAG_SELECTED);
-  gtk_style_context_add_class (style, GTK_STYLE_CLASS_VIEW);
-  gtk_style_context_get_background_color (style,
-                                          gtk_style_context_get_state (style),
-                                          &color);
-  if (color.alpha == 0.)
-    {
-      gtk_style_context_remove_class (style, GTK_STYLE_CLASS_VIEW);
-      gtk_style_context_get_background_color (style,
-                                              gtk_style_context_get_state (style),
-                                              &color);
-    }
-  gtk_style_context_restore (style);
-#else
-  style = gtk_widget_get_style (GTK_WIDGET (data->widget));
-  color = style->bg[GTK_STATE_SELECTED];
-#endif
+  context = gtk_widget_get_style_context (data->widget);
+  msd_get_background_color (context, GTK_STATE_FLAG_SELECTED, &color);
 
-  cairo_save (cr);
-  cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
   cairo_set_source_rgba (cr, 1., 1., 1., 0.);
+  cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
   cairo_paint (cr);
 
   for (i = 0; i <= N_CIRCLES; i++)
@@ -114,18 +101,12 @@ locate_pointer_paint (MsdLocatePointerData *data,
       if (circle_progress >= 1.)
 	continue;
 
-      if (composited)
+      if (composite)
 	{
 	  cairo_set_source_rgba (cr,
-#if GTK_CHECK_VERSION (3, 0, 0)
 				 color.red,
 				 color.green,
 				 color.blue,
-#else
-				 color.red / 65535.,
-				 color.green / 65535.,
-				 color.blue / 65535.,
-#endif
 				 1 - circle_progress);
 	  cairo_arc (cr,
 		     width / 2,
@@ -157,46 +138,39 @@ locate_pointer_paint (MsdLocatePointerData *data,
 	  cairo_stroke (cr);
 	}
     }
-  cairo_restore (cr);
+}
+
+static gboolean
+locate_pointer_draw (GtkWidget      *widget,
+                     cairo_t        *cr,
+                     gpointer        user_data)
+{
+  MsdLocatePointerData *data = (MsdLocatePointerData *) user_data;
+
+  if (gtk_cairo_should_draw_window (cr, data->window))
+    locate_pointer_paint (data, cr, gtk_widget_is_composited (data->widget));
+
+  return TRUE;
 }
 
 static void
 update_shape (MsdLocatePointerData *data)
 {
   cairo_t *cr;
-#if GTK_CHECK_VERSION (3, 0, 0)
-  cairo_surface_t *mask;
   cairo_region_t *region;
+  cairo_surface_t *mask;
 
-  mask = gdk_window_create_similar_image_surface (data->window,
-                                                  CAIRO_FORMAT_A1,
-                                                  WINDOW_SIZE,
-                                                  WINDOW_SIZE,
-                                                  0);
+  mask = cairo_image_surface_create (CAIRO_FORMAT_A1, WINDOW_SIZE, WINDOW_SIZE);
   cr = cairo_create (mask);
-
-  locate_pointer_paint (data, cr, FALSE);
-
   region = gdk_cairo_region_create_from_surface (mask);
 
-  gdk_window_shape_combine_region (data->window, region, 0, 0);
-
-  cairo_region_destroy (region);
-  cairo_destroy (cr);
-  cairo_surface_destroy (mask);
-#else
-  GdkBitmap *mask;
-
-  mask = gdk_pixmap_new (data->window, WINDOW_SIZE, WINDOW_SIZE, 1);
-  cr = gdk_cairo_create (mask);
-
   locate_pointer_paint (data, cr, FALSE);
 
-  gdk_window_shape_combine_mask (data->window, mask, 0, 0);
+  gdk_window_shape_combine_region (data->window, region, 0, 0);
+  cairo_region_destroy (region);
 
   cairo_destroy (cr);
-  g_object_unref (mask);
-#endif
+  cairo_surface_destroy (mask);
 }
 
 static void
@@ -205,48 +179,34 @@ timeline_frame_cb (MsdTimeline *timeline,
 		   gpointer     user_data)
 {
   MsdLocatePointerData *data = (MsdLocatePointerData *) user_data;
-  GdkScreen *screen = gdk_window_get_screen (data->window);
-#if GTK_CHECK_VERSION (3, 20, 0)
-  GdkDisplay *display = gdk_window_get_display (data->window);
-  GdkSeat *seat;
-  GdkDevice *pointer;
-#elif GTK_CHECK_VERSION (3, 0, 0)
-  GdkDisplay *display = gdk_window_get_display (data->window);
+  GdkScreen *screen;
   GdkDeviceManager *device_manager;
   GdkDevice *pointer;
-#endif
   gint cursor_x, cursor_y;
 
-  if (gdk_screen_is_composited (screen))
+  if (gtk_widget_is_composited (data->widget))
     {
-      gtk_widget_queue_draw (GTK_WIDGET (data->widget));
+      gdk_window_invalidate_rect (data->window, NULL, FALSE);
       data->progress = progress;
     }
   else if (progress >= data->progress + CIRCLES_PROGRESS_INTERVAL)
     {
       /* only invalidate window each circle interval */
       update_shape (data);
-      gtk_widget_queue_draw (GTK_WIDGET (data->widget));
+      gdk_window_invalidate_rect (data->window, NULL, FALSE);
       data->progress += CIRCLES_PROGRESS_INTERVAL;
     }
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-#if GTK_CHECK_VERSION (3, 20, 0)
-  seat = gdk_display_get_default_seat (display);
-  pointer = gdk_seat_get_pointer (seat);
-#else
-  device_manager = gdk_display_get_device_manager (display);
+  screen = gdk_window_get_screen (data->window);
+  device_manager = gdk_display_get_device_manager (gdk_window_get_display (gdk_screen_get_root_window (screen)));
   pointer = gdk_device_manager_get_client_pointer (device_manager);
-#endif
-  gdk_device_get_position (pointer,
-                           NULL,
-                           &cursor_x,
-                           &cursor_y);
-#else
-  gdk_window_get_pointer (gdk_screen_get_root_window (screen),
-                          &cursor_x, &cursor_y, NULL);
-#endif
-  gtk_window_move (data->widget,
+  gdk_window_get_device_position (gdk_screen_get_root_window (screen),
+                                  pointer,
+                                  &cursor_x,
+                                  &cursor_y,
+                                  NULL);
+
+  gdk_window_move (data->window,
                    cursor_x - WINDOW_SIZE / 2,
                    cursor_y - WINDOW_SIZE / 2);
 }
@@ -254,67 +214,28 @@ timeline_frame_cb (MsdTimeline *timeline,
 static void
 set_transparent_shape (GdkWindow *window)
 {
-#if GTK_CHECK_VERSION (3, 0, 0)
-  cairo_t *cr;
-  cairo_surface_t *mask;
   cairo_region_t *region;
 
-  mask = gdk_window_create_similar_image_surface (window,
-                                                  CAIRO_FORMAT_A1,
-                                                  WINDOW_SIZE,
-                                                  WINDOW_SIZE,
-                                                  0);
-  cr = cairo_create (mask);
-#else
-  cairo_t *cr;
-  GdkBitmap *mask;
-
-  mask = gdk_pixmap_new (data->window, WINDOW_SIZE, WINDOW_SIZE, 1);
-  cr = gdk_cairo_create (mask);
-#endif
-
-  cairo_set_source_rgba (cr, 1., 1., 1., 0.);
-  cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
-  cairo_paint (cr);
-
-#if GTK_CHECK_VERSION (3, 0, 0)
-  region = gdk_cairo_region_create_from_surface (mask);
-
-  gdk_window_shape_combine_region (window, region, 0, 0);
+  region = cairo_region_create ();
 
+  gdk_window_input_shape_combine_region (data->window, region, 0, 0);
   cairo_region_destroy (region);
-  cairo_destroy (cr);
-  cairo_surface_destroy (mask);
-#else
-  gdk_window_shape_combine_mask (data->window, mask, 0, 0);
-
-  cairo_destroy (cr);
-  g_object_unref (mask);
-#endif
 }
 
 static void
 unset_transparent_shape (GdkWindow *window)
 {
-#if GTK_CHECK_VERSION (3, 0, 0)
-  gdk_window_shape_combine_region (window, NULL, 0, 0);
-#else
-  gdk_window_shape_combine_mask (window, NULL, 0, 0);
-#endif
+  gdk_window_shape_combine_region (data->window, NULL, 0, 0);
 }
 
 static void
-composited_changed (GdkScreen            *screen,
+composited_changed (GtkWidget            *widget,
                     MsdLocatePointerData *data)
 {
-  if (gdk_screen_is_composited (screen))
-    {
-      unset_transparent_shape (data->window);
-    }
+  if (!gtk_widget_is_composited (widget))
+    set_transparent_shape (data->window);
   else
-    {
-      set_transparent_shape (data->window);
-    }
+    unset_transparent_shape (data->window);
 }
 
 static void
@@ -322,78 +243,34 @@ timeline_finished_cb (MsdTimeline *timeline,
 		      gpointer     user_data)
 {
   MsdLocatePointerData *data = (MsdLocatePointerData *) user_data;
-  GdkScreen *screen = gdk_window_get_screen (data->window);
 
   /* set transparent shape and hide window */
-  if (!gdk_screen_is_composited (screen))
-    {
-      set_transparent_shape (data->window);
-    }
+  if (!gtk_widget_is_composited (data->widget))
+    set_transparent_shape (data->window);
 
-  gtk_widget_hide (GTK_WIDGET (data->widget));
+  gdk_window_hide (data->window);
 }
 
 static void
-locate_pointer_unrealize_cb (GtkWidget            *widget,
-                             MsdLocatePointerData *data)
+create_window (MsdLocatePointerData *data,
+	       GdkScreen            *screen)
 {
-  if (data->window != NULL)
-    {
-#if GTK_CHECK_VERSION (3, 0, 0)
-      gtk_widget_unregister_window (GTK_WIDGET (data->widget),
-                                    data->window);
-#else
-      gdk_window_set_user_data (data->window, NULL);
-#endif
-      gdk_window_destroy (data->window);
-    }
-  data->window = NULL;
-}
-
-static void
-locate_pointer_realize_cb (GtkWidget            *widget,
-                           MsdLocatePointerData *data)
-{
-  GdkScreen *screen;
-#if !GTK_CHECK_VERSION (3, 0, 0)
-  GdkColormap *colormap;
-#endif
   GdkVisual *visual;
   GdkWindowAttr attributes;
   gint attributes_mask;
 
-  screen = gtk_window_get_screen (data->widget);
-#if !GTK_CHECK_VERSION (3, 0, 0)
-  colormap = gdk_screen_get_rgba_colormap (screen);
-#endif
   visual = gdk_screen_get_rgba_visual (screen);
 
-#if !GTK_CHECK_VERSION (3, 0, 0)
-  if (colormap == NULL)
-    colormap = gdk_screen_get_system_colormap (screen);
-#endif
   if (visual == NULL)
     visual = gdk_screen_get_system_visual (screen);
 
-  locate_pointer_unrealize_cb (GTK_WIDGET (data->widget), data);
-
   attributes_mask = GDK_WA_X | GDK_WA_Y;
-#if !GTK_CHECK_VERSION (3, 0, 0)
-  if (colormap != NULL)
-    {
-      attributes_mask |= GDK_WA_COLORMAP;
-    }
-#endif
+
   if (visual != NULL)
-    {
-      attributes_mask |= GDK_WA_VISUAL;
-    }
+    attributes_mask = attributes_mask | GDK_WA_VISUAL;
 
   attributes.window_type = GDK_WINDOW_TEMP;
   attributes.wclass = GDK_INPUT_OUTPUT;
-#if !GTK_CHECK_VERSION (3, 0, 0)
-  attributes.colormap = colormap;
-#endif
   attributes.visual = visual;
   attributes.event_mask = GDK_VISIBILITY_NOTIFY_MASK | GDK_EXPOSURE_MASK;
   attributes.width = 1;
@@ -403,59 +280,9 @@ locate_pointer_realize_cb (GtkWidget            *widget,
 				 &attributes,
 				 attributes_mask);
 
-  gtk_widget_set_window (GTK_WIDGET (data->widget),
-                         data->window);
-#if GTK_CHECK_VERSION (3, 0, 0)
-  gtk_widget_register_window (GTK_WIDGET (data->widget),
-                              data->window);
-#else
-  gdk_window_set_user_data (data->window, GTK_WIDGET (data->widget));
-#endif
+  gdk_window_set_user_data (data->window, data->widget);
 }
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-static gboolean
-locate_pointer_draw_cb (GtkWidget      *widget,
-                        cairo_t        *cr,
-                        gpointer        user_data)
-{
-  MsdLocatePointerData *data = (MsdLocatePointerData *) user_data;
-  GdkScreen *screen = gdk_window_get_screen (data->window);
-
-  if (gtk_cairo_should_draw_window (cr, data->window))
-    {
-      locate_pointer_paint (data, cr, gdk_screen_is_composited (screen));
-    }
-
-  return TRUE;
-}
-#else
-static gboolean
-locate_pointer_expose_event_cb (GtkWidget      *widget,
-                                GdkEventExpose *event,
-                                gpointer        user_data)
-{
-  MsdLocatePointerData *data = (MsdLocatePointerData *) user_data;
-  GdkScreen *screen = gdk_window_get_screen (data->window);
-  cairo_t *cr;
-
-  if (event->window != data->window)
-    {
-      return FALSE;
-    }
-
-  cr = gdk_cairo_create (data->window);
-
-  gdk_cairo_rectangle (cr, &event->area);
-  cairo_clip (cr);
-
-  locate_pointer_paint (data, cr, gdk_screen_is_composited (screen));
-
-  cairo_destroy (cr);
-  return TRUE;
-}
-#endif
-
 static MsdLocatePointerData *
 msd_locate_pointer_data_new (GdkScreen *screen)
 {
@@ -466,27 +293,12 @@ msd_locate_pointer_data_new (GdkScreen *screen)
   /* this widget will never be shown, it's
    * mainly used to get signals/events from
    */
-  data->widget = GTK_WINDOW (gtk_window_new (GTK_WINDOW_POPUP));
+  data->widget = gtk_window_new (GTK_WINDOW_POPUP);
+  gtk_widget_realize (data->widget);
 
-  g_signal_connect (GTK_WIDGET (data->widget), "unrealize",
-                    G_CALLBACK (locate_pointer_unrealize_cb),
-                    data);
-  g_signal_connect (GTK_WIDGET (data->widget), "realize",
-                    G_CALLBACK (locate_pointer_realize_cb),
-                    data);
-#if GTK_CHECK_VERSION (3, 0, 0)
   g_signal_connect (G_OBJECT (data->widget), "draw",
-                    G_CALLBACK (locate_pointer_draw_cb),
+                    G_CALLBACK (locate_pointer_draw),
                     data);
-#else
-  g_signal_connect (G_OBJECT (data->widget), "expose-event",
-                    G_CALLBACK (locate_pointer_expose_event_cb),
-                    data);
-#endif
-
-  gtk_window_set_screen (data->widget, screen);
-  gtk_widget_set_app_paintable (GTK_WIDGET (data->widget), TRUE);
-  gtk_widget_realize (GTK_WIDGET (data->widget));
 
   data->timeline = msd_timeline_new (ANIMATION_LENGTH);
   g_signal_connect (data->timeline, "frame",
@@ -494,6 +306,8 @@ msd_locate_pointer_data_new (GdkScreen *screen)
   g_signal_connect (data->timeline, "finished",
 		    G_CALLBACK (timeline_finished_cb), data);
 
+  create_window (data, screen);
+
   return data;
 }
 
@@ -501,91 +315,31 @@ static void
 move_locate_pointer_window (MsdLocatePointerData *data,
 			    GdkScreen            *screen)
 {
-#if GTK_CHECK_VERSION (3, 20, 0)
-  GdkDisplay *display;
-  GdkSeat *seat;
-  GdkDevice *pointer;
-#elif GTK_CHECK_VERSION (3, 0, 0)
-  GdkDisplay *display;
   GdkDeviceManager *device_manager;
   GdkDevice *pointer;
-#endif
   gint cursor_x, cursor_y;
-  cairo_t *cr;
-#if GTK_CHECK_VERSION (3, 0, 0)
-  cairo_surface_t *mask;
-  cairo_region_t *region;
-#else
-  GdkBitmap *mask;
-#endif
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-  display = gdk_screen_get_display (screen);
-#if GTK_CHECK_VERSION (3, 20, 0)
-  seat = gdk_display_get_default_seat (display);
-  pointer = gdk_seat_get_pointer (seat);
-#else
-  device_manager = gdk_display_get_device_manager (display);
+  device_manager = gdk_display_get_device_manager (gdk_window_get_display (gdk_screen_get_root_window (screen)));
   pointer = gdk_device_manager_get_client_pointer (device_manager);
-#endif
-  gdk_device_get_position (pointer,
-                           NULL,
-                           &cursor_x,
-                           &cursor_y);
-#else
-  gdk_window_get_pointer (gdk_screen_get_root_window (screen),
-                          &cursor_x,
-                          &cursor_y,
-                          NULL);
-#endif
+  gdk_window_get_device_position (gdk_screen_get_root_window (screen),
+                                  pointer,
+                                  &cursor_x,
+                                  &cursor_y,
+                                  NULL);
 
-  gtk_window_move (data->widget,
-                   cursor_x - WINDOW_SIZE / 2,
-                   cursor_y - WINDOW_SIZE / 2);
-  gtk_window_resize (data->widget,
-                     WINDOW_SIZE, WINDOW_SIZE);
+  gdk_window_move_resize (data->window,
+                          cursor_x - WINDOW_SIZE / 2,
+                          cursor_y - WINDOW_SIZE / 2,
+                          WINDOW_SIZE, WINDOW_SIZE);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-  mask = gdk_window_create_similar_image_surface (data->window,
-                                                  CAIRO_FORMAT_A1,
-                                                  WINDOW_SIZE,
-                                                  WINDOW_SIZE,
-                                                  0);
-  cr = cairo_create (mask);
-
-  cairo_set_source_rgba (cr, 0., 0., 0., 0.);
-  cairo_paint (cr);
-
-  region = gdk_cairo_region_create_from_surface (mask);
-
-  /* allow events to happen through the window */
-  gdk_window_input_shape_combine_region (data->window, region, 0, 0);
-
-  cairo_region_destroy (region);
-  cairo_destroy (cr);
-  cairo_surface_destroy (mask);
-#else
-  mask = gdk_pixmap_new (data->window, WINDOW_SIZE, WINDOW_SIZE, 1);
-  cr = gdk_cairo_create (mask);
-
-  cairo_set_source_rgba (cr, 0., 0., 0., 0.);
-  cairo_paint (cr);
-
-  /* allow events to happen through the window */
-  gdk_window_input_shape_combine_mask (data->window, mask, 0, 0);
-
-  cairo_destroy (cr);
-  g_object_unref (mask);
-#endif
+  gdk_window_input_shape_combine_region (data->window, NULL, 0, 0);
 }
 
 void
 msd_locate_pointer (GdkScreen *screen)
 {
-  if (data == NULL)
-    {
-      data = msd_locate_pointer_data_new (screen);
-    }
+  if (!data)
+    data = msd_locate_pointer_data_new (screen);
 
   msd_timeline_pause (data->timeline);
   msd_timeline_rewind (data->timeline);
@@ -593,19 +347,20 @@ msd_locate_pointer (GdkScreen *screen)
   /* Create again the window if it is not for the current screen */
   if (gdk_screen_get_number (screen) != gdk_screen_get_number (gdk_window_get_screen (data->window)))
     {
-      gtk_widget_unrealize (GTK_WIDGET (data->widget));
-      gtk_window_set_screen (data->widget, screen);
-      gtk_widget_realize (GTK_WIDGET (data->widget));
+      gdk_window_set_user_data (data->window, NULL);
+      gdk_window_destroy (data->window);
+
+      create_window (data, screen);
     }
 
   data->progress = 0.;
 
-  g_signal_connect (screen, "composited-changed",
+  g_signal_connect (data->widget, "composited-changed",
                     G_CALLBACK (composited_changed), data);
 
   move_locate_pointer_window (data, screen);
-  composited_changed (screen, data);
-  gtk_widget_show (GTK_WIDGET (data->widget));
+  composited_changed (data->widget, data);
+  gdk_window_show (data->window);
 
   msd_timeline_start (data->timeline);
 }
@@ -620,14 +375,11 @@ filter (GdkXEvent *xevent,
         GdkEvent  *event,
         gpointer   data)
 {
-  GdkScreen *screen;
-  GdkDisplay *display;
   XEvent *xev = (XEvent *) xevent;
   guint keyval;
   gint group;
 
-  screen = (GdkScreen *)data;
-  display = gdk_screen_get_display (screen);
+  GdkScreen *screen = (GdkScreen *)data;
 
   if (xev->type == KeyPress || xev->type == KeyRelease)
     {
@@ -646,23 +398,9 @@ filter (GdkXEvent *xevent,
               XAllowEvents (xev->xkey.display,
                             SyncKeyboard,
                             xev->xkey.time);
-              XGrabButton (xev->xkey.display,
-                           AnyButton,
-                           AnyModifier,
-                           xev->xkey.window,
-                           False,
-                           ButtonPressMask,
-                           GrabModeSync,
-                           GrabModeAsync,
-                           None,
-                           None);
             }
           else
             {
-              XUngrabButton (xev->xkey.display,
-                             AnyButton,
-                             AnyModifier,
-                             xev->xkey.window);
               XAllowEvents (xev->xkey.display,
                             AsyncKeyboard,
                             xev->xkey.time);
@@ -674,26 +412,10 @@ filter (GdkXEvent *xevent,
           XAllowEvents (xev->xkey.display,
                         ReplayKeyboard,
                         xev->xkey.time);
-          XUngrabButton (xev->xkey.display,
-                         AnyButton,
-                         AnyModifier,
-                         xev->xkey.window);
-          XUngrabKeyboard (xev->xkey.display,
+          XUngrabKeyboard (gdk_x11_get_default_xdisplay (),
                            xev->xkey.time);
         }
     }
-  else if (xev->type == ButtonPress)
-    {
-      XAllowEvents (xev->xbutton.display,
-                    ReplayPointer,
-                    xev->xbutton.time);
-      XUngrabButton (xev->xbutton.display,
-                     AnyButton,
-                     AnyModifier,
-                     xev->xbutton.window);
-      XUngrabKeyboard (xev->xbutton.display,
-                       xev->xbutton.time);
-    }
 
   return GDK_FILTER_CONTINUE;
 }
@@ -707,7 +429,7 @@ set_locate_pointer (void)
   int n_keys;
   gboolean has_entries;
   static const guint keyvals[] = { GDK_KEY_Control_L, GDK_KEY_Control_R };
-  unsigned int j;
+  unsigned j;
 
   display = gdk_display_get_default ();
   n_screens = gdk_display_get_n_screens (display);
@@ -723,13 +445,13 @@ set_locate_pointer (void)
           gint i, j;
           for (i = 0; i < n_keys; i++)
             {
-              for (j = 0; j < n_screens; j++)
+              for (j=0; j< n_screens; j++)
                 {
                   GdkScreen *screen;
                   Window xroot;
 
                   screen = gdk_display_get_screen (display, j);
-                  xroot = GDK_WINDOW_XID (gdk_screen_get_root_window (screen));
+                  xroot = gdk_x11_window_get_xid (gdk_screen_get_root_window (screen));
 
                   XGrabKey (GDK_DISPLAY_XDISPLAY (display),
                             keys[i].keycode,
